@@ -5,9 +5,12 @@ from nose import tools
 def test_string():
     tools.eq_(
         Formatter.format_string('''a = 'b' '''),
-        '''a = 'b'\n''',
+        '''a = 'b'\n\n''',
     )
 
+    formatter = Formatter()
+    formatter.format_path('tests/samples/continuations.py')
+
 
 def test_string_type():
     x = types.StringTokenType(-255, 'TEST')
@@ -16,24 +19,40 @@ def test_string_type():
 
     tools.eq_(
         Formatter.format_string("a = '''b'''"),
-        '''a = 'b'\n''',
+        '''a = 'b'\n\n''',
     )
 
     tools.eq_(
         Formatter.format_string('''a = """b'c"""'''),
-        "a = '''b'c'''\n",
+        "a = '''b'c'''\n\n",
     )
 
     tools.eq_(
         Formatter.format_string('''a = "b'c"'''),
-        "a = '''b'c'''\n",
+        "a = '''b'c'''\n\n",
     )
 
     tools.eq_(
         Formatter.format_string('a = """b"""'),
-        '''a = 'b'\n''',
+        '''a = 'b'\n\n''',
+    )
+
+    tools.eq_(
+        Formatter.format_string('''a = """b'c"""'''),
+        "a = '''b'c'''\n\n",
+    )
+
+    tools.eq_(
+        Formatter.format_string('''a = """b\'\'\'c"""'''),
+        'a = """b\'\'\'c"""\n\n',
+    )
+
+    tools.eq_(
+        Formatter.format_string('''a = "b\'\'\'c"'''),
+        'a = "b\'\'\'c"\n\n',
     )
 
 if __name__ == '__main__':
     from base_test import main
     main('-vv')
+
